@@ -5,10 +5,10 @@ package Inline::CPP::Config;
 use strict;
 use warnings;
 
-our $VERSION = '0.75';
+our $VERSION = '0.80';
 #$VERSION = eval $VERSION; ## no critic (eval)
 
-our $compiler = 'g++ -D_REENTRANT -D_GNU_SOURCE -fwrapv -fno-strict-aliasing -pipe -fstack-protector-strong -I/usr/local/include -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64 -xc++';
+our $compiler = 'g++ -D_REENTRANT -D_GNU_SOURCE -fwrapv -fno-strict-aliasing -pipe -fstack-protector-strong -I/usr/local/include -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64 -D_FORTIFY_SOURCE=2 -xc++';
 our $libs     = '-lstdc++';
 
 our $iostream_fn = 'iostream';
